@@ -2,7 +2,7 @@
 if (!isset($gCms)) exit;
 if (!$this->HasPermission()) exit;
 
-$tabs_available = array('events', 'categories', 'summarytemplates', 'detailtemplates','registrationtemplates', 'preferences');
+$tabs_available = array('events', 'categories', 'summarytemplates', 'detailtemplates','registrationtemplates', 'registrationslisttemplates', 'preferences');
 
 echo $this->StartTabHeaders();
 foreach ($tabs_available as $tab_name)
