@@ -27,7 +27,11 @@ $event_smarty = $event->get_smarty_object();
 if ($event->allow_registration)
 {
 	$aliased_title = munge_string_to_url($event->name);
-	$prettyurl = $this->GetPreference('urlprefix', 'events').'/'.$this->GetPreference('registerurlprefix', 'register').'/'.$event->id.'/'.$detailpage.'/'.$aliased_title;
+	
+	$urlprefix = $this->GetPrefix('events');
+	$registrationurlprefix = $this->GetPrefix('register');
+
+	$prettyurl = $urlprefix.'/'.$registrationurlprefix.'/'.$event->id.'/'.$detailpage.'/'.$aliased_title;
 	
 	$event_smarty->registration_url = $this->CreateFrontendLink($id, $returnid, 'registration', '', array('event_id'=>$event->id), '', 1, $inline, '', '', $prettyurl);
 }
