@@ -12,7 +12,7 @@ class EventsManager_events_ops
 		start_datetime / end_datetime : if "show=custom", only display the events that are valid for the start and end datetime
 		myevents : if true, only display the current FEUser events (to which he is registered to)
 	*/
-	static public function get_events($status='published', $category_id='', $category_name='', $show='all', $start_datetime='', $end_datetime='', $myevents=false)
+	static public function get_events($status='published', $category_id='', $category_name='', $show='all', $start_datetime='', $end_datetime='', $myevents=false, $sortby='name', $sortorder='ASC')
 	{
 		$db = cmsms()->GetDb();
 		$query = 'SELECT e.* FROM '.cms_db_prefix().'module_events e';
@@ -130,7 +130,7 @@ class EventsManager_events_ops
 			$qparams[] = $id_user;
 		}
 		
-		$query .=' ORDER BY `name`';
+		$query .=' ORDER BY `' . $sortby . '` ' . $sortorder;
 		$res = $db->GetArray($query, $qparams);
 		
 		$events = array();
